document.addEventListener('DOMContentLoaded', function() {
    // Mobile menu toggle
    const mobileMenu = document.querySelector('.mobile-menu');
    const navLinks = document.querySelector('.nav-links');
    
    mobileMenu.addEventListener('click', () => {
        navLinks.classList.toggle('active');
    });

    // Generate button functionality
    const generateBtn = document.getElementById('generate-btn');
    const brandName = document.getElementById('brand-name');
    const industry = document.getElementById('industry');
    const toneSlider = document.getElementById('tone-slider');
    const styleGuideContent = document.getElementById('style-guide-content');

    // Sample voice characteristics based on thought leaders
    const voiceCharacteristics = {
        tech: ['innovative', 'visionary', 'transformative'],
        finance: ['strategic', 'analytical', 'authoritative'],
        healthcare: ['empathetic', 'trustworthy', 'professional'],
        education: ['inspiring', 'nurturing', 'enlightening']
    };

    generateBtn.addEventListener('click', () => {
        if (!brandName.value || !industry.value) {
            alert('Please fill in all fields');
            return;
        }

        const toneLevel = parseInt(toneSlider.value);
        const selectedIndustry = voiceCharacteristics[industry.value];
        
        // Generate style guide content
        const styleGuide = generateStyleGuide(
            brandName.value,
            selectedIndustry,
            toneLevel
        );

        // Animate and display results
        styleGuideContent.style.opacity = '0';
        setTimeout(() => {
            styleGuideContent.innerHTML = styleGuide;
            styleGuideContent.style.opacity = '1';
        }, 200);
    });

    function generateStyleGuide(brand, characteristics, toneLevel) {
        const toneDescriptors = [
            'conservative and formal',
            'professional and balanced',
            'conversational and friendly',
            'energetic and engaging',
            'bold and passionate'
        ];

        return `
            <div class="style-guide">
                <h4>${brand}'s Voice & Tone Guide</h4>
                <p><strong>Voice Characteristics:</strong><br>
                ${characteristics.join(', ')}</p>
                <p><strong>Tone Level:</strong><br>
                ${toneDescriptors[toneLevel - 1]}</p>
                <p><strong>Writing Guidelines:</strong><br>
                • Use ${toneLevel > 3 ? 'active' : 'balanced'} voice<br>
                • Focus on ${toneLevel > 3 ? 'impact' : 'clarity'}<br>
                • Maintain ${toneLevel < 3 ? 'formal' : 'conversational'} language</p>
            </div>
        `;
    }

    // Smooth scrolling for navigation links
    document.querySelectorAll('a[href^="#"]').forEach(anchor => {
        anchor.addEventListener('click', function (e) {
            e.preventDefault();
            const target = document.querySelector(this.getAttribute('href'));
            target.scrollIntoView({
                behavior: 'smooth',
                block: 'start'
            });
        });
    });
});
